summaryrefslogtreecommitdiff
path: root/scripts/build/arch
diff options
context:
space:
mode:
authorKeith Packard <keithp@keithp.com>2020-09-16 18:51:26 (GMT)
committerKeith Packard <keithp@keithp.com>2020-09-16 18:52:58 (GMT)
commitc1c475d0a0c930d236413e3c1e304ca4fd6ab4a3 (patch)
tree43239a4ed7cfbf842ec166f4ce88df098caa7e0f /scripts/build/arch
parente6e39ea63bb6f8b129e0c028493d0469ba19c9e2 (diff)
Map picolibc to suitable CT_TARGET_SYS values
picolibc is another bare-metal C library, and so should be mapped to CT_TARGET_SYS just like newlib does. Signed-off-by: Keith Packard <keithp@keithp.com>
Diffstat (limited to 'scripts/build/arch')
-rw-r--r--scripts/build/arch/powerpc.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/build/arch/powerpc.sh b/scripts/build/arch/powerpc.sh
index 36a727a..85c64d1 100644
--- a/scripts/build/arch/powerpc.sh
+++ b/scripts/build/arch/powerpc.sh
@@ -7,12 +7,12 @@ CT_DoArchTupleValues () {
# Only override values when ABI is not the default
case "${CT_ARCH_powerpc_ABI}" in
eabi)
# EABI is only for bare-metal, so libc ∈ [none,newlib]
CT_TARGET_SYS="eabi"
;;
spe)
case "${CT_LIBC}" in
- none|newlib) CT_TARGET_SYS="elfspe";;
+ none|newlib|picolibc) CT_TARGET_SYS="elfspe";;
*glibc) CT_TARGET_SYS="gnuspe";;
uClibc) CT_TARGET_SYS="uclibcgnuspe";;
esac
@@ -7,12 +7,12 @@ CT_DoArchTupleValues () {
case "${CT_ARCH_powerpc_ABI}" in
eabi)
- # EABI is only for bare-metal, so libc ∈ [none,newlib]
+ # EABI is only for bare-metal, so libc ∈ [none,newlib,picolibc]
CT_TARGET_SYS="eabi"
;;